==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebBaseEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescription } from "./WebBaseEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebBaseEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebBaseEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebBaseEventArgsDetailDescriptionMetadata.a == null) {
                WebBaseEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebBaseEventArgsDetailDescriptionMetadata.c(WebBaseEventArgsDetailDescriptionMetadata.a);
            }
            if (a.j(WebBaseEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.y(WebBaseEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:BaseEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Owner", "Unknown");
        }
        static d(a) {
            WebBaseEventArgsDetailDescriptionMetadata.b(a);
            a.aa("WebBaseEventArgsDetail", () => new WebBaseEventArgsDetailDescription());
            a.z("WebBaseEventArgsDetail", WebBaseEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebBaseEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebBaseEventArgsDetailDescriptionMetadata, 'WebBaseEventArgsDetailDescriptionMetadata');
    WebBaseEventArgsDetailDescriptionMetadata.a = null;
    return WebBaseEventArgsDetailDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebBaseEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescription } from "./WebBaseEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebBaseEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebBaseEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebBaseEventArgsDetailDescriptionMetadata.a == null) {
                WebBaseEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebBaseEventArgsDetailDescriptionMetadata.c(WebBaseEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebBaseEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebBaseEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:BaseEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Owner", "Unknown");
        }
        static d(a) {
            WebBaseEventArgsDetailDescriptionMetadata.b(a);
            a.ac("WebBaseEventArgsDetail", () => new WebBaseEventArgsDetailDescription());
            a.ab("WebBaseEventArgsDetail", WebBaseEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebBaseEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebBaseEventArgsDetailDescriptionMetadata, 'WebBaseEventArgsDetailDescriptionMetadata');
    WebBaseEventArgsDetailDescriptionMetadata.a = null;
    return WebBaseEventArgsDetailDescriptionMetadata;
})();
